function [t_obs, p_obs] = pressure_gilmore(t, R, U, pb, rho_infty, c_infty, p_infty, r, B, n);
% [t_obs, p_obs] = pressure_gilmore(t, R, U, pb, rho_infty, c_infty, p_infty, r, B, n);
%
% Compute the pressure field in the liquid at distance r from the center of
% the bubble using the second-order approximation from Gilmore (1952)

H = n .* ((p_infty+B)./((n-1)*rho_infty)) .* (((pb+B)./(p_infty+B)).^((n-1)/n)-1); %enthalpy
y = R .* (H + (U.^2)/2); %outgoing constant characteristic
K3 = (c_infty.^3.*R.^2.*U./y.^2).*(1-U.^2./(2*c_infty.^2)) - ...
    (c_infty^2.*R./y).*(1-U./c_infty); %outgoing constant characteristic

t_obs = t + ((r-R)./c_infty).*(1 - (U.*R)./(c_infty.*r)); %time
u_obs = y./(c_infty.*r) + ((K3.*y.^2)./(c_infty^3*r.^2)).*(1 - y./(c_infty^2.*r) + ...
    (K3.^2.*y.^4)./(2*c_infty^8*r.^4)); %velocity field
p_obs = rho_infty.*(y./r -u_obs.^2/2) + (rho_infty/(2*c_infty^2)).*...
    (y./r - u_obs.^2/2).^2; %pressure field

end