function [t_obs, p_obs] = pressure_keller(t, R, U, rho_infty, c_infty, r)
% [t_obs, p_obs] = pressure_keller(t, R, U, rho_infty, r)
%
% Compute the pressure field in the liquid at distance r from the center of
% the bubble using the volume formulation of Keller and  Kolodner (1956). 
% The second derivative of the radius is computed by
% finite difference approximations.

A = (U(2:end)-U(1:end-1))./(t(2:end)-t(1:end-1)); %finite difference approximation 
                                                  %to acceleration of bubble wall   

t = t(1:end-1); R = R(1:end-1); U = U(1:end-1); %adjust length of vectors to match 
                                                %finite difference approximation for acceleration                                           
                      
t_sig = t + (r-R)./c_infty; %time vector when signal arrives
delta_t = mean(diff(t))/100; %spacing between time steps before signal arrives
t_bef = [min(t):delta_t:min(t_sig)]'; %time vector before signal arrives
t_obs = [t_bef; t_sig]; %time vector, for before and after signal arrives

p_sig = rho_infty * ((2*R.*U.^2+A.*R.^2)./r - R.^4.*U.^2./(2*r^4)); %pressure signal
p_bef = zeros(length(t_bef),1);

p_obs = [p_bef; p_sig]; %pressure perturbation, for before and after signal arrives

end

