function [] = AirgunBubbleSolve(airgunParams, physConst)

[m,n] = size(airgunParams);

for i = 1:m;
    
    airgunInit = airgun_initialization(airgunParams(i,:), physConst);
    bubbleInit = bubble_initialization(airgunInit, physConst);
    
    initCond = initCond_save(bubbleInit, airgunInit);
    params = params_save(bubbleInit, airgunInit, physConst);
    
    [t, Y] = ode45(@modified_herring_eqn, physConst.time, initCond, [], params);
    
    R = Y(:,1); U = Y(:,2);
    
    [tDir, pDir] = pressure_eqn(t, R, U, physConst.rho_infty, physConst.c_infty, physConst.r); %direct arrival
    [tGhost, pGhost] = pressure_eqn(t, R, U, physConst.rho_infty, physConst.c_infty, ... %ghost
        physConst.r + 2*physConst.depth);
    
    dt = 5e-4;
    tInterp = min(tDir):dt:max(tDir);
    pDirInterp = pchip(tDir, pDir, tInterp);
    pGhostInterp = pchip(tGhost, pGhost, tInterp);
    
    pPres = pDirInterp - pGhostInterp;
    
    [f, P] = pressure_spectra(tInterp, pPres*physConst.r);
    semilogx(f, P,'LineWidth',2); hold on;
     
end
