function [f, P] = pressure_spectra(tPres, pPres)
% [f, P] = pressure_spectra(t, p)

fs = 32000;
dt = 1/fs;

t_int = min(tPres):dt:max(tPres); %form a regular grid
p_int = pchip(tPres, pPres, t_int); %interpolate onto a regular grid

L = length(t_int); %length of signal
Fs = 1/((max(t_int)-min(t_int))/L); %sampling frequency
NFFT = 2^nextpow2(L); %next power of 2 from length

P = fft(p_int, NFFT)*dt; %Fourier Transform
P = abs(P(1:NFFT/2+1)); %single sided amplitude spectrum

refP = 1e-6; %reference value for sound in water
P = mag2db((P/refP)); %convert to dBs

f = (Fs/2)*linspace(0,1,NFFT/2+1); %frequency vector

